@@ -610,7 +610,7 @@ void CalendarView::updateConfig(const QByteArray &receiver)
 
     Q_EMIT configChanged();
 
-    //switch beetween merged, side by side and tabbed agenda if needed
+    //switch between merged, side by side and tabbed agenda if needed
     mViewManager->updateMultiCalendarDisplay();
 
     // To make the "fill window" configurations work
@@ -1912,7 +1912,7 @@ void CalendarView::processIncidenceSelection(const Akonadi::Item &item, const QD
 
     if (incidence->type() == KCalCore::Incidence::TypeTodo) {
         todo = true;
-        subtodo = (incidence->relatedTo() != QString());
+        subtodo = !incidence->relatedTo().isEmpty();
     }
     Q_EMIT todoSelected(todo);
     Q_EMIT subtodoSelected(subtodo);
